float4x4 matWorldViewProj;
float4x4 matWorld;
float3x3 matTangent;

float4 vecViewPos;
float4 vecSunDir;
float4 vecSkill41;

texture entSkin1;
texture entSkin2;
texture mtlSkin1;

sampler2D colorMap = sampler_state {Texture=<entSkin1>;};
sampler2D normalMap = sampler_state {Texture=<entSkin2>;};
samplerCUBE CubeMap = sampler_state {Texture=<mtlSkin1>;};

void metalVS(	in float4 pos			:POSITION,
					in float3 N				:NORMAL,
					in float2 tex			:TEXCOORD0,
					in float3 tangent		:TEXCOORD2,
					out float4 oPos		:POSITION,
					out float3 viewToPos	:TEXCOORD0,
					out float2 oTex		:TEXCOORD1,
					out float3 oLight		:TEXCOORD2,
					out float3x3 WTT		:TEXCOORD3)
{	
	float3x3 worldToTangentSpace;
	worldToTangentSpace[0] = mul(tangent, matWorld);
	worldToTangentSpace[1] = mul(cross(tangent, N), matWorld);
	worldToTangentSpace[2] = mul(N, matWorld);
	
	WTT=worldToTangentSpace;
	
	float3 worldPos = mul(pos,matWorld);
	float3 viewDir = worldPos-vecViewPos;
	//viewToPos = normalize(mul(worldToTangentSpace,viewDir));
	viewToPos = normalize(viewDir);
	//oLight = normalize(mul(worldToTangentSpace,-vecSunDir));
	oLight = -vecSunDir;
	
	oPos = mul(pos,matWorldViewProj);
	oTex = tex;
}

float4 metalPS(	in float3 viewToPos	:TEXCOORD0,
						in float2 texcrd		:TEXCOORD1,
						in float3 light		:TEXCOORD2,
						in float3x3 WTT		:TEXCOORD3):COLOR
{
	float3 bumpNormals = 2*tex2D(normalMap,texcrd).xyz-1;
	bumpNormals = mul(bumpNormals,WTT);
	float3 cubeTexcrd = reflect(viewToPos,bumpNormals);//2*bumpNormals*dot(bumpNormals,viewToPos)-viewToPos;//;
	float4 cube = texCUBE(CubeMap,cubeTexcrd);
	float4 Color = tex2D(colorMap,texcrd);
	float diffuse = saturate(dot(bumpNormals,light));
	float3 reflect = normalize(2*diffuse*bumpNormals-light);
	float spec = pow(saturate(dot(reflect,-viewToPos)),8);
	//return float4(cubeTexcrd,1.0f);
	//return (dot(viewToPos,cubeTexcrd)+1)*0.5;
	//return Color+spec*0.3;
	return lerp(Color,cube,vecSkill41.x)*min(diffuse+0.4f,1.0f)+spec*vecSkill41.y;
}

technique metal
{
	pass p0
	{
		vertexshader = compile vs_2_0 metalVS();
		pixelshader = compile ps_2_0 metalPS();
	}
}